==> escapework-manager-0.4.0-9a43a3.tar: src/views/users/form.blade.php <==
@extends('manager::layouts.master')

@section('content')
    <div class="page-header">
        <div class="pull-left">
            <h1>Usuários</h1>
        </div><!-- .pull-left --> 

        <div class="pull-right">
            <a href="{{ route('manager.users.index') }}" class="btn">Voltar</a>
        </div><!-- .pull-right -->

        <div class="clearfix"></div> 
    </div><!-- .page-header --> 

    {{ Msg::getAll() }}

    <form action="{{ !$edit ? route('manager.users.store') : route('manager.users.update', $user->id) }}" method="post" id="form-usuario" class="form-horizontal">
        @if ($edit)
            <input type="hidden" name="_method" value="put" />
        @endif

        <fieldset>
            <div class="control-group">
                <label for="role_id" class="control-label">Perfil</label>

                <div class="controls">
                    <select name="role_id" id="role_id" class="input-xlarge">
                        <option value="">Selecione o perfil</option>
                        {{ $role->HTMLOptions($user->role_id) }}
                    </select>
                </div><!-- .controls --> 
            </div><!-- .control-group --> 

            <div class="control-group">
                <label for="name" class="control-label">Nome</label>

                <div class="controls">
                    <input type="text" name="name" id="name" class="input-xxlarge" value="{{ $user->name }}" autofocus />
                </div><!-- .controls --> 
            </div><!-- .control-group --> 

            <div class="control-group">
                <label for="email" class="control-label">E-mail</label>

                <div class="controls">
                    <input type="email" name="email" id="email" class="input-xxlarge" value="{{ $user->email }}" />
                </div><!-- .controls --> 
            </div><!-- .control-group --> 

            <div class="control-group">
                <label for="password" class="control-label">Senha</label>

                <div class="controls">
                    <input type="password" name="password" id="password" class="input-xxlarge" />

                    @if ($edit)
                        <span class="help-block">Apenas se for editar a senha</span>
                    @endif
                </div><!-- .controls --> 
            </div><!-- .control-group --> 

            @if (count($extraFields) > 0)
                <hr />
                
                @foreach ($extraFields as $field)
                    <div class="control-group">
                        <label for="{{ $field['field'] }}" class="control-label">{{ $field['label'] }}</label>

                        <div class="controls">
                            <input type="{{ $field['type'] }}" name="{{ $field['field'] }}" id="{{ $field['field'] }}" value="{{ $user->$field['field'] }}" class="input-xxlarge" {{ implode(' ', $field['attrs'])}} /> 
                        </div><!-- .controls --> 
                    </div><!-- .control-group --> 
                @endforeach
            @endif

            <div class="form-actions">
                <input type="submit" class="btn btn-primary" value="Salvar" /> 
                <a href="{{ route('manager.users.index') }}" class="btn">Cancelar</a>
            </div><!-- .form-actions --> 
        </fieldset>
    </form>
@stop

==> escapework-manager-0.8.0-9a300b.tar: src/views/users/form.blade.php <==
@extends(Config::get('manager::views.layouts.master'))

@section('content')
    <ul class="breadcrumb">
        <li><a href="{{ route('manager.home') }}">Home</a> <span class="divider">/</span></li>
        <li><a href="{{ route('manager.users.index') }}">Usuários</a> <span class="divider">/</span></li>
        <li class="active">{{ $edit ? 'Editar' : 'Inserir' }}</li>
    </ul><!-- .breadcrumb -->

    <div class="page-header">
        <div class="pull-left">
            <h2>Usuários</h2>
        </div><!-- .pull-left -->

        <div class="pull-right">
            <a href="{{ route('manager.users.index') }}" class="btn">Voltar</a>
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    </div><!-- .page-header -->

    {{ Msg::getAll() }}

    <form action="{{ !$edit ? route('manager.users.store') : route('manager.users.update', $user->id) }}" method="post" id="form-usuario" class="form-horizontal">
        @if ($edit)
            <input type="hidden" name="_method" value="put" />
        @endif

        <fieldset>
            <div class="control-group">
                <label for="role_id" class="control-label">Perfil</label>

                <div class="controls">
                    <select name="role_id" id="role_id" class="input-xlarge">
                        <option value="">Selecione o perfil</option>
                        {{ $role->HTMLOptions($user->role_id) }}
                    </select>
                </div><!-- .controls -->
            </div><!-- .control-group -->

            <div class="control-group">
                <label for="name" class="control-label">Nome</label>

                <div class="controls">
                    <input type="text" name="name" id="name" class="input-xxlarge" value="{{ $user->name }}" autofocus />
                </div><!-- .controls -->
            </div><!-- .control-group -->

            <div class="control-group">
                <label for="email" class="control-label">E-mail</label>

                <div class="controls">
                    <input type="email" name="email" id="email" class="input-xxlarge" value="{{ $user->email }}" />
                </div><!-- .controls -->
            </div><!-- .control-group -->

            <div class="control-group">
                <label for="password" class="control-label">Senha</label>

                <div class="controls">
                    <input type="password" name="password" id="password" class="input-xxlarge" />

                    @if ($edit)
                        <span class="help-block">Apenas se for editar a senha</span>
                    @endif
                </div><!-- .controls -->
            </div><!-- .control-group -->

            <div class="form-actions">
                <input type="submit" class="btn btn-primary js-btn-submit" value="Salvar" data-loading-text="Carregando..." />
                <a href="{{ route('manager.users.index') }}" class="btn">Cancelar</a>
            </div><!-- .form-actions -->
        </fieldset>
    </form>
@stop

@section('scripts')
    @parent
    <script type="text/javascript">
    (function() {
        $('#form-usuario').on('submit', function(e) {
            $('.js-btn-submit').button('loading');
        });
    })();
    </script>
@stop
